summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorNalin Dahyabhai <nalin@src.gnome.org>2003-01-31 16:43:53 +0000
committerNalin Dahyabhai <nalin@src.gnome.org>2003-01-31 16:43:53 +0000
commit60357a7641accec8282c33e7c6f33ea12d3bbfe1 (patch)
tree05082d6b318eefc93dce1feed8eaa30abe456a32
parentea3f576c95466cb6f6a4ee759a7396e520ff6554 (diff)
downloadvte-60357a7641accec8282c33e7c6f33ea12d3bbfe1.tar.gz
pull up selection-always-extending-by-default fix from HEAD, ok
* src/vte.c: pull up selection-always-extending-by-default fix from HEAD, ok release-team. * vte.spec: 0.10.16
-rw-r--r--ChangeLog5
-rw-r--r--src/vte.c25
-rw-r--r--vte.spec5
3 files changed, 24 insertions, 11 deletions
diff --git a/ChangeLog b/ChangeLog
index 8acfb507..faf6eec8 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,8 @@
+2003-01-31 nalin
+ * src/vte.c: pull up selection-always-extending-by-default fix from
+ HEAD, ok release-team.
+ * vte.spec: 0.10.16
+
2003-01-30 Fatih Demir <kabalak@gtranslator.org>
* configure.in: Added "tr" (Turkish) to the languages' list.
diff --git a/vte.spec b/vte.spec
index e5b256b5..5e7b972b 100644
--- a/vte.spec
+++ b/vte.spec
@@ -1,5 +1,5 @@
Name: vte
-Version: 0.10.15
+Version: 0.10.16
Release: 1
Summary: An experimental terminal emulator.
License: LGPL
@@ -93,6 +93,9 @@ rm -f $RPM_BUILD_ROOT/%{_libdir}/python*/site-packages/*.a
%{_libdir}/pkgconfig/*
%changelog
+* Fri Jan 31 2003 Nalin Dahyabhai <nalin@redhat.com> 0.10.16-1
+- fix "selection always extends by default" bug
+
* Wed Jan 22 2003 Nalin Dahyabhai <nalin@redhat.com> 0.10.15-1
- make mouse modes mutually-exclusive
- update background immediately on realize
diff --git a/src/vte.c b/src/vte.c
index b9e4ce8a..c41e80dc 100644
--- a/src/vte.c
+++ b/src/vte.c
@@ -7125,8 +7125,8 @@ vte_terminal_process_incoming(gpointer data)
}
}
- /* Add the cell we just moved to the region we need to
- * refresh for the user. */
+ /* Add the cell into which we just moved to the region we
+ * need to refresh for the user. */
bbox_topleft.x = MIN(bbox_topleft.x,
screen->cursor_current.col);
bbox_topleft.y = MIN(bbox_topleft.y,
@@ -9532,14 +9532,19 @@ vte_terminal_button_press(GtkWidget *widget, GdkEventButton *event)
fprintf(stderr, "Handling click ourselves.\n");
}
#endif
- /* If the user hit shift, override event mode. */
- if ((terminal->pvt->modifiers & GDK_SHIFT_MASK) ||
- !event_mode) {
- /* If shift is pressed in non-event
- * mode, extend selection if the cell
- * isn't already selected, otherwise
- * start selection. */
- if (terminal->pvt->has_selection &&
+ /* If we're in event mode, and the user held down the
+ * shift key, we start selecting. */
+ if (event_mode) {
+ if (terminal->pvt->modifiers & GDK_SHIFT_MASK) {
+ start_selecting = TRUE;
+ }
+ } else {
+ /* If the user hit shift, and the location
+ * clicked isn't selected, and we already have
+ * a selection, extend selection, otherwise
+ * start over. */
+ if ((terminal->pvt->modifiers & GDK_SHIFT_MASK) &&
+ terminal->pvt->has_selection &&
!vte_cell_is_selected(terminal,
cellx,
celly,